package su.xash.engine.ui.library

import android.annotation.SuppressLint
import android.content.Intent
import android.os.Bundle
import android.util.Log
import android.view.LayoutInflater
import android.view.Menu
import android.view.MenuInflater
import android.view.MenuItem
import android.view.View
import android.view.ViewGroup
import androidx.core.view.MenuProvider
import androidx.fragment.app.Fragment
import androidx.fragment.app.activityViewModels
import androidx.lifecycle.Lifecycle
import androidx.lifecycle.lifecycleScope
import androidx.lifecycle.repeatOnLifecycle
import androidx.navigation.fragment.findNavController
import kotlinx.coroutines.launch
import su.xash.engine.R
import su.xash.engine.adapters.GameAdapter
import su.xash.engine.databinding.FragmentLibraryBinding

class LibraryFragment : Fragment(), MenuProvider {
    private var _binding: FragmentLibraryBinding? = null
    private val binding get() = _binding!!

    private val libraryViewModel: LibraryViewModel by activityViewModels()

    override fun onCreateView(
        inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?
    ): View? {
        _binding = FragmentLibraryBinding.inflate(inflater, container, false)

        val adapter = GameAdapter(libraryViewModel)
        binding.gamesList.adapter = adapter

        requireActivity().addMenuProvider(this, viewLifecycleOwner, Lifecycle.State.RESUMED)

        return binding.root
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        binding.swipeRefresh.setOnRefreshListener { libraryViewModel.reloadGames(requireContext()) }

        libraryViewModel.isReloading.observe(viewLifecycleOwner) {
            binding.swipeRefresh.isRefreshing = it
        }

        libraryViewModel.installedGames.observe(viewLifecycleOwner) {
            (binding.gamesList.adapter as GameAdapter).submitList(it)
        }

        libraryViewModel.workInfos.observe(viewLifecycleOwner) {
            libraryViewModel.refreshDownloads(requireContext())
        }

        libraryViewModel.downloads.observe(viewLifecycleOwner) {
            libraryViewModel.reloadGames(requireContext())
        }
    }

    override fun onDestroyView() {
        super.onDestroyView()
        _binding = null
    }

    override fun onCreateMenu(menu: Menu, menuInflater: MenuInflater) {
        menuInflater.inflate(R.menu.menu_library, menu)
    }

    override fun onMenuItemSelected(menuItem: MenuItem): Boolean {
        when (menuItem.itemId) {
            R.id.action_browse -> {
                startActivity(
                    Intent(Intent.ACTION_VIEW).setDataAndType(
                        null, "vnd.android.document/directory"
                    )
                )
            }

            R.id.action_install -> {
                findNavController().navigate(R.id.action_libraryFragment_to_setupFragment)
            }

            R.id.action_settings -> {
                findNavController().navigate(R.id.action_libraryFragment_to_appSettingsFragment)
            }
        }

        return false
    }
}